# ronswanson
![CI](https://github.com/grburgess/ronswanson/workflows/CI/badge.svg?branch=master)
[![codecov](https://codecov.io/gh/grburgess/ronswanson/branch/master/graph/badge.svg)](https://codecov.io/gh/grburgess/ronswanson)
[![Documentation Status](https://readthedocs.org/projects/ronswanson/badge/?version=latest)](http://jmichaelburgess.com/ronswanson/index.html)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.3372456.svg)](https://doi.org/10.5281/zenodo.3372456)
![PyPI](https://img.shields.io/pypi/v/ronswanson)
![PyPI - Downloads](https://img.shields.io/pypi/dm/ronswanson)

![alt text](https://raw.githubusercontent.com/grburgess/ronswanson/master/docs/media/logo.png)


Ron Swanson builds tables for 3ML.

This tool provides an easy interface to construct 3ML table models from
computational expensive simulations on HPC systems. Why? Because it is your
right to do so!

## Installation

```sh
pip install ronswanson
```
or

```sh
git clone https://github.com/grburgess/ronswanson
cd ronswanson
python setup.py install
```


## Credits
Inspiration by Elisa Schoesser.
